@@ -143,6 +143,7 @@ void View::run()
 	fpsCycles = 0;
 
 	render();
+	fade(FADE_IN);
 
 	SDL_ShowCursor(0);
 
@@ -220,8 +221,16 @@ void View::run()
 
 			if (newEvent && handleMenuEvent(ev)) {
 				menuActive = false;
-				if (!game.isDemo())
+				if (game.state == VGS_PAUSED) {
 					game.pause(false);
+				} else if (!game.isDemo()){
+					/* new game, fade in */
+					render();
+					fade(FADE_IN);
+					/* reset passed time */
+					ticks.reset();
+					ms = 1;
+				}
 			}
 		}
 
@@ -299,8 +308,7 @@ void View::run()
 
 	SDL_ShowCursor(1);
 
-	if (!quitReceived)
-		dim();
+	fade();
 }
 
 /** Render current game state. */
@@ -339,20 +347,23 @@ void View::render()
 	}
 }
 
-/* Dim screen to black. As game engine is already set for new state
- * we cannot use render() but need current screen state. */
-void View::dim()
+/* Fade in or out current screen content. For fading in
+ * SDL_RenderPresent must not have been called yet. */
+void View::fade(int style)
 {
-	Texture img;
-	img.createFromScreen();
+	Texture tex;
+	tex.createFromScreen();
 
-	for (uint8_t a = 250; a > 0; a -= 10) {
+	for (uint8_t alpha = 255; alpha > 0; alpha -= 5) {
 		SDL_SetRenderDrawColor(mrc,0,0,0,255);
 		SDL_RenderClear(mrc);
-		img.setAlpha(a);
-		img.copy();
+		if (style == FADE_OUT)
+			tex.setAlpha(alpha);
+		else
+			tex.setAlpha(255 - alpha);
+		tex.copy();
 		SDL_RenderPresent(mrc);
-		SDL_Delay(10);
+		SDL_Delay(5);
 	}
 
 	/* make sure no input is given yet for next state */
@@ -512,7 +523,7 @@ void View::createMenus()
 			_("Select theme. (not applied yet)"),
 			AID_NONE,vconfig.themeid,themeNames));
 	mGraphics->add(new MenuItemList(_("Mode"),
-			_("Select mode. (not applied yet)"),
+			_("Select mode. (not applied yet)\n\nSmall window: 25% of screen height\nMedium window: 50% of screen height\nLarge window: 67% of screen height"),
 			AID_NONE,vconfig.windowmode,windowModeNames,4));
 	mGraphics->add(new MenuItem(_("Apply Theme&Mode"),
 			_("Apply the above settings."),AID_APPLYTHEMEMODE));
@@ -747,7 +758,8 @@ bool View::handleMenuEvent(SDL_Event &ev)
 			//showHelp();
 			break;
 		case AID_STARTGAME:
-			menuActive = false;
+			fade();
+			ret = true; /* leave root menu */
 			waitForInputRelease();
 			game.init(vconfig.gametype);
 			keystate.reset();
